#!/bin/bash

# redirect stderr to stdin
exec 2>&1

# stop on any error
set -ex

# define the setup command, but preserve EUPS_PATH
. "/tigress/pprice/hscPipe7/lsstsw/eups/2.1.5/bin/setups.sh"
export EUPS_PATH="/tigress/pprice/hscPipe7/lsstsw/stack"

cd "/tigress/pprice/hscPipe7/lsstsw/build/scipy"

# clean up the working directory
git reset --hard
git clean -d -f -q -x -e '_build.*'

# prepare
eupspkg PRODUCT=scipy VERSION=0.0.1.lsst1-2-g5722128 FLAVOR=generic prep

# setup the package with its exact dependencies
cat > _build.tags <<-EOF
	python               0.0.7-3-g85c3855
	numpy                1.13.1-2-g36a8a36
EOF
set +x
echo "Setting up environment with EUPS"
setup --vro=_build.tags -r .
set -x

# build
eupspkg PRODUCT=scipy VERSION=0.0.1.lsst1-2-g5722128 FLAVOR=generic config
eupspkg PRODUCT=scipy VERSION=0.0.1.lsst1-2-g5722128 FLAVOR=generic build
if [ -d  tests/.tests ] &&                 [ "`ls tests/.tests/*.failed 2> /dev/null | wc -l`" -ne 0 ]; then
    echo "*** Failed unit tests.";
    exit 1
fi
eupspkg PRODUCT=scipy VERSION=0.0.1.lsst1-2-g5722128 FLAVOR=generic install

# declare to EUPS
eupspkg PRODUCT=scipy VERSION=0.0.1.lsst1-2-g5722128 FLAVOR=generic decl

# explicitly append SHA1 to pkginfo
echo SHA1=5722128f0573a5c8c70d4d13521152fc4aad04b9 >> $(eups list scipy 0.0.1.lsst1-2-g5722128 -d)/ups/pkginfo
